Learn R Programming

hdiVAR (version 1.0.2)

kalman: kalman filtering and smoothing for vector autoregression with measurement error

Description

kalman filtering and smoothing for vector autoregression with measurement error

Usage

kalman(Y,A,sig_eta,sig_epsilon,X_init=NULL,P_init=NULL)

Value

a list of conditional expectations and covariances of \(x_t\)'s.

Arguments

Y

observations of time series, a p by T matrix.

A

current estimate of transition matrix.

sig_eta

current estiamte of \(\sigma_\eta\).

sig_epsilon

current estiamte \(\sigma_\epsilon\).

X_init

inital estimate of latent \(x_1\) at the first iteration, a p-dimensional vector.

P_init

inital covariance estimate of latent \(x_1\) at the first iteration, a p by p matrix.

Author

Xiang Lyu, Jian Kang, Lexin Li