kalman filtering and smoothing for vector autoregression with measurement error
kalman(Y,A,sig_eta,sig_epsilon,X_init=NULL,P_init=NULL)a list of conditional expectations and covariances of \(x_t\)'s.
observations of time series, a p by T matrix.
current estimate of transition matrix.
current estiamte of \(\sigma_\eta\).
current estiamte \(\sigma_\epsilon\).
inital estimate of latent \(x_1\) at the first iteration, a p-dimensional vector.
inital covariance estimate of latent \(x_1\) at the first iteration, a p by p matrix.
Xiang Lyu, Jian Kang, Lexin Li